@@ -119,79 +119,58 @@ class QA:
         qa_hash = self._flags["qa_hash"]
         jsonify = self._flags["json"]
 
-        table = Table()
-        table.add_column("Microservice", style="purple", no_wrap=True)
-        table.add_column("Branch", style="green")
-        table.add_column("Drone build")
-        table.add_column("Status", style="white")
-        console = Console()
-
         r = self._qainit.execute(
             "GET",
             f"/api/v1/qa/{qa_hash}",
         )
-        try:
-            resources_list = r.json()["list"]["resources"]
-            for resource in resources_list:
-                if resource["type"] == "microservice":
-                    drone_url = (
-                        "[blue][u]"
-                        + "https://drone-1.prima.it/primait/"
-                        + resource["name"]
-                        + "/"
-                        + resource["promoted_build"]
-                        + "[/u][/blue]"
-                    )
-                    table.add_row(
-                        resource["name"],
-                        resource["ref"],
-                        drone_url,
-                        resource["status"],
-                    )
-            if jsonify:
-                print(json.dumps(r.json(), indent=2))
-            else:
-                print(
-                    f"""
-> Prima url: https://www-{qa_hash}.prima.qa
-> Backoffice (Borat) url: https://backoffice-{qa_hash}.prima.qa
-> Urania url: http://urania-{qa_hash}.prima.qa
-> Bburago url: http://bburago-{qa_hash}.prima.qa
-> Ermes url: http://ermes-{qa_hash}.prima.qa
-> Hal9000 url: http://hal9000{qa_hash}.prima.qa
-> Fidaty url: http://fidaty-{qa_hash}.prima.qa
-> Peano url: http://peano-{qa_hash}.prima.qa
-> Assange url: https://assange-{qa_hash}.prima.qa
-> Activia url: http://activia-{qa_hash}.prima.qa
-> Skynet url: http://skynet-{qa_hash}.prima.qa
-> Roger url: http://roger-{qa_hash}.prima.qa
-> Leftorium url: http://leftoriu-{qa_hash}.prima.qa
-> Rachele url: http://rachele-{qa_hash}.prima.qa
-> Maia App url: https://api-{qa_hash}.prima.qa
-> Maia Intermediari url: https://api-intermediari-{qa_hash}.prima.qa
-> Maia Casa url: https://api-casa-{qa_hash}.prima.qa
-> Maia Pagamenti url: https://api-pagamenti-{qa_hash}.prima.qa
-> Maia Sostituzioni url: https://api-sostituzioni-{qa_hash}.prima.qa
-> Legion url: http://legion-{qa_hash}.prima.qa
-> Crash url: https://crash-{qa_hash}.prima.qa
-> Starsky url: https://starsky-{qa_hash}.prima.qa
-> Hutch url: https://hutch-{qa_hash}.prima.qa
-> Vianello url: https://vianello-{qa_hash}.prima.qa
-> Domus url: https://domus-{qa_hash}.prima.qa
-> Lira url: https://lira-{qa_hash}.prima.qa
-> Baggio url: https://baggio-{qa_hash}.prima.qa
-> Mario url: https://mario-{qa_hash}.prima.qa
-> Mario Backend url: https://api-mario-{qa_hash}.prima.qa
-> Zuhause url: https://zuhause-{qa_hash}.prima.qa
-> Pyxis url: https://pyxis-{qa_hash}.prima.qa
-> Caritas url: https://caritas-{qa_hash}.prima.qa
-> Cashabck url: https://cashback-{qa_hash}.prima.qa
-> Evvivass url: https://evvivass-{qa_hash}.prima.qa
-                """
+        if jsonify:
+            print(json.dumps(r.json(), sort_keys=True, indent=2))
+        else:
+            table = Table()
+            table.add_column("Microservice", style="purple", no_wrap=True)
+            table.add_column("Drone build")
+            table.add_column("Branch", style="white")
+            table.add_column("Status", style="white")
+
+            dns_table = Table()
+            dns_table.add_column("Name", style="purple", no_wrap=True)
+            dns_table.add_column("Record", style="green")
+
+            console = Console()
+
+            try:
+                resources_list = sorted(
+                    r.json()["list"]["resources"], key=lambda k: k["name"]
                 )
+                for resource in resources_list:
+                    if (
+                        resource["type"] == "microservice"
+                        or "service" in resource["name"]
+                    ) and resource["dns"]:
+                        for key, value in resource["dns"].items():
+                            dns_table.add_row(key, value)
+                    if resource["type"] == "microservice":
+                        drone_url = (
+                            "[blue][u]"
+                            + "https://drone-1.prima.it/primait/"
+                            + resource["name"]
+                            + "/"
+                            + resource["promoted_build"]
+                            + "[/u][/blue]"
+                        )
+                        table.add_row(
+                            resource["name"],
+                            drone_url,
+                            resource["ref"]
+                            if resource["ref"] == "master"
+                            else f"[green]{resource['ref']}[/green]",
+                            resource["status"],
+                        )
+
+                console.print(dns_table)
                 console.print(table)
-        except TypeError:
-            logger.error("Wrong hash")
+            except TypeError:
+                logger.error("Wrong hash")
 
     def _delete(self):
         qa_hash = self._flags
